@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom165.h,v 1.8.2.1 2006/03/14 21:01:47 aesok Exp $ */
+/* $Id: iom165.h,v 1.10.2.2 2008/01/06 20:10:43 arcanum Exp $ */
 
 /* avr/iom165.h - definitions for ATmega165 */
 
@@ -767,4 +767,44 @@
 #define E2END           0x1FF
 #define FLASHEND        0x3FFF
 
+
+/* Fuses */
+
+#define FUSE_MEMORY_SIZE 3
+
+/* Low Fuse Byte */
+#define FUSE_CKSEL0      ~_BV(0)
+#define FUSE_CKSEL1      ~_BV(1)
+#define FUSE_CKSEL2      ~_BV(2)
+#define FUSE_CKSEL3      ~_BV(3)
+#define FUSE_SUT0        ~_BV(4)
+#define FUSE_SUT1        ~_BV(5)
+#define FUSE_CKOUT       ~_BV(6)
+#define FUSE_CKDIV8      ~_BV(7)
+#define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
+
+/* High Fuse Byte */
+#define FUSE_BOOTRST     ~_BV(0)
+#define FUSE_BOOTSZ0     ~_BV(1)
+#define FUSE_BOOTSZ1     ~_BV(2)
+#define FUSE_EESAVE      ~_BV(3)
+#define FUSE_WDTON       ~_BV(4)
+#define FUSE_SPIEN       ~_BV(5)
+#define FUSE_JTAGEN      ~_BV(6)
+#define FUSE_OCDEN       ~_BV(7)
+#define HFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1 & FUSE_SPIEN & FUSE_JTAGEN)
+
+/* Extended Fuse Byte */
+#define FUSE_BODLEVEL0   ~_BV(1)
+#define FUSE_BODLEVEL1   ~_BV(2)
+#define FUSE_BODLEVEL2   ~_BV(3)
+#define EFUSE_DEFAULT (0xFF)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+#define __BOOT_LOCK_BITS_0_EXIST
+#define __BOOT_LOCK_BITS_1_EXIST 
+
+
 #endif /* _AVR_IOM165_H_ */
