@@ -1,5 +1,5 @@
 /* Copyright (c) 2002, 2004 Marek Michalkiewicz
-   Copyright (c) 2005, 2006 Eric B. Weddington
+   Copyright (c) 2005, 2006, 2007 Eric B. Weddington
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -29,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: wdt.h,v 1.22.2.5 2006/04/19 16:53:25 aesok Exp $ */
+/* $Id: wdt.h,v 1.44.2.7 2008/03/25 22:33:29 arcanum Exp $ */
 
 /*
    avr/wdt.h - macros for AVR watchdog timer
@@ -41,6 +41,7 @@
 #include <avr/io.h>
 #include <stdint.h>
 
+/** \file */
 /** \defgroup avr_watchdog <avr/wdt.h>: Watchdog timer handling
     \code #include <avr/wdt.h> \endcode
 
@@ -69,7 +70,7 @@
     #include <stdint.h>
     #include <avr/wdt.h>
 
-    uint8_t mcusr_mirror;
+    uint8_t mcusr_mirror _attribute_ ((section (".noinit")));
 
     void get_mcusr(void) \
       __attribute__((naked)) \
@@ -83,8 +84,8 @@
     \endcode
 
     Saving the value of MCUSR in \c mcusr_mirror is only needed if the
-    application later wants to examine the reset source, but clearing
-    in particular the watchdog reset flag before disabling the
+    application later wants to examine the reset source, but in particular, 
+    clearing the watchdog reset flag before disabling the
     watchdog is required, according to the datasheet.
 */
 
@@ -92,15 +93,17 @@
    \ingroup avr_watchdog
    Reset the watchdog timer.  When the watchdog timer is enabled,
    a call to this instruction is required before the timer expires,
-   otherwise a watchdog-initiated device reset will occur. */
+   otherwise a watchdog-initiated device reset will occur. 
+*/
 
 #define wdt_reset() __asm__ __volatile__ ("wdr")
 
+
 #if defined(WDP3)
 # define _WD_PS3_MASK       _BV(WDP3)
 #else
 # define _WD_PS3_MASK       0x00
-#endif /* WDP3 */
+#endif
 
 #if defined(WDTCSR)
 #  define _WD_CONTROL_REG     WDTCSR
@@ -115,25 +118,99 @@
 #endif
 
 
-#if defined (__AVR_ATmega169__) || defined(__AVR_AT90CAN128__) \
-|| defined(__AVR_AT90CAN32__) || defined(__AVR_AT90CAN64__) \
-|| defined(__AVR_AT90USB646__) || defined(__AVR_AT90USB647__) \
-|| defined(__AVR_AT90USB1286__) || defined(__AVR_AT90USB1287__) \
-|| defined(__AVR_ATmega48__) || defined(__AVR_ATmega88__) \
-|| defined(__AVR_ATmega164P__) \
-|| defined(__AVR_ATmega165__) || defined(__AVR_ATmega168__) \
-|| defined(__AVR_ATmeg324P__) \
-|| defined(__AVR_ATmega325__) || defined(__AVR_ATmega3250__) \
-|| defined(__AVR_ATmega329__) || defined(__AVR_ATmega3290__) \
+
+#if defined(__AVR_ATxmega128A1__) \
+|| defined(__AVR_ATxmega64A1__)
+
+
+/**
+   \ingroup avr_watchdog
+   Enable the watchdog timer, configuring it for expiry after
+   \c timeout (which is a combination of the \c WDP0 through
+   \c WDP2 bits to write into the \c WDTCR register; For those devices 
+   that have a \c WDTCSR register, it uses the combination of the \c WDP0 
+   through \c WDP3 bits).
+
+   See also the symbolic constants \c WDTO_15MS et al.
+*/
+
+/*
+    wdt_enable(WDT_PER_8KCLK_gc);
+*/
+#define wdt_enable(value) \
+__asm__ __volatile__ ( \
+    "in __tmp_reg__, %0 \n\t" \
+    "out %1, %3 \n\t" \
+    "sts %2, %4 \n\t" \
+    "wdr \n\t" \
+    "out %0, __tmp_reg__ \n\t" \
+    : /* no outputs */ \
+    : "=M" (_SFR_MEM_ADDR(RAMPD)), \
+      "=M" (_SFR_MEM_ADDR(CCP)), \
+      "=M" (_SFR_MEM_ADDR(WDT_CTRL)) \
+      "r" (0xD8), \
+      "r" ((uint8_t)(WDT_CEN_bm | WDT_ENABLE_bm | value)), \
+    : "r0" \
+)
+
+#elif defined(__AVR_AT90PWM1__) \
+|| defined(__AVR_AT90PWM216__) \
+|| defined(__AVR_AT90PWM2B__) \
+|| defined(__AVR_AT90PWM316__) \
+|| defined(__AVR_AT90PWM3B__) \
+|| defined(__AVR_AT90PWM2__) \
+|| defined(__AVR_AT90PWM3__) \
+|| defined(__AVR_AT90CAN32__) \
+|| defined(__AVR_AT90CAN64__) \
+|| defined(__AVR_AT90CAN128__) \
+|| defined(__AVR_ATmega1284P__) \
+|| defined(__AVR_ATmega165__) \
+|| defined(__AVR_ATmega165P__) \
+|| defined(__AVR_ATmega168P__) \
+|| defined(__AVR_ATmega169__) \
+|| defined(__AVR_ATmega169P__) \
+|| defined(__AVR_ATmega325__) \
+|| defined(__AVR_ATmega3250__) \
+|| defined(__AVR_ATmega328P__) \
+|| defined(__AVR_ATmega329__) \
+|| defined(__AVR_ATmega3290__) \
+|| defined(__AVR_ATmega32C1__) \
+|| defined(__AVR_ATmega32HVB__) \
+|| defined(__AVR_ATmega32M1__) \
+|| defined(__AVR_ATmega32U4__) \
 || defined(__AVR_ATmega406__) \
+|| defined(__AVR_ATmega48P__) \
+|| defined(__AVR_ATmega645__) \
+|| defined(__AVR_ATmega6450__) \
+|| defined(__AVR_ATmega649__) \
+|| defined(__AVR_ATmega6490__) \
+|| defined(__AVR_ATmega88P__) \
+|| defined(__AVR_ATmega48__) \
+|| defined(__AVR_ATmega88__) \
+|| defined(__AVR_ATmega168__) \
 || defined(__AVR_ATmega640__) \
-|| defined(__AVR_ATmega644__) || defined(__AVR_ATmega644P__) \
-|| defined(__AVR_ATmega645__) || defined(__AVR_ATmega6450__) \
-|| defined(__AVR_ATmega649__) || defined(__AVR_ATmega6490__) \
-|| defined(__AVR_ATmega1280__) || defined(__AVR_ATmega1281__) \
-|| defined(__AVR_AT90PWM2__) || defined(__AVR_AT90PWM3__)
+|| defined(__AVR_ATmega1280__) \
+|| defined(__AVR_ATmega1281__) \
+|| defined(__AVR_ATmega2560__) \
+|| defined(__AVR_ATmega2561__) \
+|| defined(__AVR_ATmega164__) \
+|| defined(__AVR_ATmega324__) \
+|| defined(__AVR_ATmega644__) \
+|| defined(__AVR_ATmega8HVA__) \
+|| defined(__AVR_ATmega16HVA__) \
+|| defined(__AVR_ATtiny48__) \
+|| defined(__AVR_ATtiny88__) \
+|| defined(__AVR_ATtiny167__) \
+|| defined(__AVR_AT90USB82__) \
+|| defined(__AVR_AT90USB162__) \
+|| defined(__AVR_AT90USB646__) \
+|| defined(__AVR_AT90USB647__) \
+|| defined(__AVR_AT90USB1286__) \
+|| defined(__AVR_AT90USB1287__)
+
+/* Use STS instruction. */
  
-#define _wdt_write(value)   \
+#define wdt_enable(value)   \
     __asm__ __volatile__ (  \
         "in __tmp_reg__,__SREG__" "\n\t"    \
         "cli" "\n\t"    \
@@ -164,9 +241,11 @@ __asm__ __volatile__ (  \
 
 
     
-#else
+#else  
 
-#define _wdt_write(value)   \
+/* Use OUT instruction. */
+
+#define wdt_enable(value)   \
     __asm__ __volatile__ (  \
         "in __tmp_reg__,__SREG__" "\n\t"    \
         "cli" "\n\t"    \
@@ -200,21 +279,9 @@ __asm__ __volatile__ (  \
     "r" ((uint8_t)(_BV(_WD_CHANGE_BIT) | _BV(WDE))) \
     : "r0" \
 )
-    
+
 #endif
 
-/**
-   \ingroup avr_watchdog
-   Enable the watchdog timer, configuring it for expiry after
-   \c timeout (which is a combination of the \c WDP0 through
-   \c WDP2 bits to write into the \c WDTCR register; For those devices 
-   that have a \c WDTCSR register, it uses the combination of the \c WDP0 
-   through \c WDP3 bits).
-
-   See also the symbolic constants \c WDTO_15MS et al.
-*/
-#define wdt_enable(timeout) _wdt_write(timeout)
-
 
 
 /**
@@ -278,11 +345,15 @@ __asm__ __volatile__ (  \
     ATtiny25, ATtiny45, ATtiny85, 
     ATtiny261, ATtiny461, ATtiny861, 
     ATmega48, ATmega88, ATmega168,
+    ATmega48P, ATmega88P, ATmega168P, ATmega328P,
     ATmega164P, ATmega324P, ATmega644P, ATmega644,
-    ATmega640, ATmega1280, ATmega1281,
-    ATmega406,
-    AT90PWM2, AT90PWM3,
-    AT90USB646, AT90USB647, AT90USB1286, AT90USB1287.
+    ATmega640, ATmega1280, ATmega1281, ATmega2560, ATmega2561,
+    ATmega8HVA, ATmega16HVA, ATmega32HVB,
+    ATmega406, ATmega1284P,
+    AT90PWM1, AT90PWM2, AT90PWM2B, AT90PWM3, AT90PWM3B, AT90PWM216, AT90PWM316
+    AT90USB82, AT90USB162,
+    AT90USB646, AT90USB647, AT90USB1286, AT90USB1287,
+    ATtiny48, ATtiny88.
     */
 #define WDTO_4S     8
 
@@ -294,15 +365,19 @@ __asm__ __volatile__ (  \
     ATtiny25, ATtiny45, ATtiny85, 
     ATtiny261, ATtiny461, ATtiny861, 
     ATmega48, ATmega88, ATmega168,
+    ATmega48P, ATmega88P, ATmega168P, ATmega328P,
     ATmega164P, ATmega324P, ATmega644P, ATmega644,
-    ATmega640, ATmega1280, ATmega1281,
-    ATmega406,
-    AT90PWM2, AT90PWM3,
-    AT90USB646, AT90USB647, AT90USB1286, AT90USB1287.
+    ATmega640, ATmega1280, ATmega1281, ATmega2560, ATmega2561,
+    ATmega8HVA, ATmega16HVA, ATmega32HVB,
+    ATmega406, ATmega1284P,
+    AT90PWM1, AT90PWM2, AT90PWM2B, AT90PWM3, AT90PWM3B, AT90PWM216, AT90PWM316
+    AT90USB82, AT90USB162,
+    AT90USB646, AT90USB647, AT90USB1286, AT90USB1287,
+    ATtiny48, ATtiny88.
     */
 #define WDTO_8S     9
 
-#endif
-
+#endif  /* defined(__DOXYGEN__) || defined(WDP3) */
+   
 
 #endif /* _AVR_WDT_H_ */
